#
# spec file for package motion
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define spooldir /var/spool/motion

Name:           motion
Version:        4.7.0
Release:        1.1
Summary:        A motion detection system
License:        GPL-2.0-or-later
Group:          Hardware/Camera
URL:            https://motion-project.github.io/
Source0:        https://github.com/Motion-Project/motion/archive/release-%{version}.tar.gz
Source1:        motion-service
Source2:        motion-sysconfig
Patch0:         harden_motion.service.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  group(video)
BuildRequires:  libjpeg-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libmicrohttpd)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(sqlite3)
Requires(pre):  %fillup_prereq
Requires(pre):  group(video)
Requires(pre):  shadow
Provides:       group(motion)
Provides:       user(motion)
%{?systemd_requires}

%description
Motion is a software motion detector. It grabs images from video4linux devices
and/or from webcams (such as the axis network cameras). Motion is the perfect
tool for keeping an eye on your property keeping only those images that are
interesting. Motion is strictly command line driven and can run as a daemon
with a rather small footprint. This version is built with ffmpeg support but
without MySQL and PostgreSQL support.

%prep
%autosetup -p1 -n motion-release-%{version}

%build
export LIBS="-lwebp"
autoreconf -i -f
%configure \
  --without-optimizecpu \
  --without-mariadb \
  --without-mysql \
  --without-pgsql
%make_build

%install
%make_install

# We keep the main configuration file
mv %{buildroot}%{_sysconfdir}/%{name}/motion-dist.conf %{buildroot}%{_sysconfdir}/%{name}/motion.conf
rm %{buildroot}%{_sysconfdir}/%{name}/camera*-dist.conf

# We change the PID file path to match the one in the startup script
sed -i 's|; pid_file value|pid_file /var/run/motion.pid|' %{buildroot}%{_sysconfdir}/%{name}/motion.conf

sed -i 's|; target_dir value|target_dir %{spooldir}|' %{buildroot}%{_sysconfdir}/%{name}/motion.conf


install -m 0644 -D -t %{buildroot}%{_datadir}/%{name}/examples data/*.{conf,service}

mkdir -p %{buildroot}%{_unitdir}
install -c -m 0644 %{SOURCE1}  %{buildroot}%{_unitdir}/motion.service
mkdir -p %{buildroot}%{_fillupdir}
cp %{SOURCE2} %{buildroot}%{_fillupdir}/sysconfig.%{name}

mkdir -p %{buildroot}%{_sbindir}
ln -s service %{buildroot}%{_sbindir}/rcmotion

mkdir -p %{buildroot}%{spooldir}

rm -r %{buildroot}%{_datadir}/doc/motion/

rm -r %{buildroot}%{_datadir}/locale

%post
%service_add_post motion.service
%fillup_only

%postun
%service_del_postun motion.service

%pre
getent group motion || groupadd --system motion
getent passwd motion || useradd -g motion -G video -c "Motion capture daemon" -d %{spooldir} --system motion
%service_add_pre motion.service

%preun
%service_del_preun motion.service

%files
%doc doc/CHANGELOG doc/CREDITS README.md doc/*.png doc/*.html doc/*.jpg
%license LICENSE
%dir %{_sysconfdir}/%{name}
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/examples
%attr(0770,root,motion) %dir %{spooldir}
%attr(0644,root,root) %{_datadir}/%{name}/examples/motion-dist.conf
%attr(0644,root,root) %{_datadir}/%{name}/examples/motion.service
%attr(0644,root,root) %{_datadir}/%{name}/examples/camera*-dist.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}/motion.conf
%attr(0755,root,root) %{_bindir}/motion
%attr(0644,root,root) %{_mandir}/man1/motion.1*
%config %{_unitdir}/motion.service
%{_fillupdir}/sysconfig.%{name}
%{_sbindir}/rcmotion

%changelog
* Thu Jan  9 2025 Manu Maier <mmanu84@outlook.de>
- Update to 4.7.0
  * Fix zombie reaping for Motion processes
  * Fix network camera processing for non compliant codec
  * Fix v4l2M2M encoding
  * Fix fps conversion specifier
  * Allow for large date time and event numbers
  * Remove outdated MMAL camera code
* Thu Mar 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 4.6.0
  * Fix segfault on vaapi decoding
  * Remove default for allowed_media_types
  * Fix libweb includes
  * Fix autotools and translation files
  * Fix movie_extpipe
  * Fix threshold_tune
  * Implement consistent time values
  * Implement consistent calculation for pixel difference
  * Fix compiler warnings
  * Revise ioctl for devices to use long variable
  * Add support for DRM HW decode
  * Update year in copyright notice
  * Revise issue template
  * Allow for bad packets when processing file
  * Print log message of signals
- Update post-install customizations. Some entries don't exist
  anymore or are disabled in the default configuration file
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Feb  5 2024 Marcus Meissner <meissner@suse.com>
- provide user(motion) and group(motion)
* Sat Aug 26 2023 munix9@googlemail.com
- Fix undefined reference to symbol 'WebPMemoryWriterClear'
* Thu Jan  5 2023 Dirk Müller <dmueller@suse.com>
- update to 4.5.1:
  * Improve closing of v4l2 devices
  * Fix creation of pid_file
  * Add header check for mmal
  * Fix pause when used as command line option
  * Fix json pages when multiple cameras used
  * Fix codec for movie_codec for mpeg4
  * Fix rotation for v4l2 devices
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 4.5.0:
  * Do not translate the ignoring IP alert message
  * Fix processing for native_language config option
  * Add additional sleep time for images to web stream
  * Revise log level for some messages
  * Update translations
  * Update for new MariaDB pkg-config name
  * Fix cleanup when v4l2 open fails
  * Remove unused include module.
  * Remove unused H264 palette code
  * Fix sending of stale images to stream
  * Revise path when checking headers
  * Fix double free when using extpipe.
  * Revise issue template
  * Eliminate shared handle for sqlite3
  * Fix setting of controls for v4l2 devices
  * Fix processing for v4l2 devices when stride is not width
  * Replace dbeventid with eventid
  * Fix parsing of PGM files
  * Fix scale of text when in debug mode
  * Fix processing when camera is not initially available
  * Fix double free when camera is lost frequently.
  * Fix close on exec methods
  * Fix processing for preferred codec with new ffmpeg versions
  * Fix snapshots when using netcam high
  * Enhance netcam processing for single jpg pages
  * Update instructions on using libcamerify for pi camera
  * Update instructions on maximum number of cameras shown on web control page.
  * Expand buffer for log messages
  * Update japanese translations.
  * Fix extra event triggered upon quit
* Sun Nov 28 2021 Jonas Kvinge <jonaski@opensuse.org>
- Update to 4.4.0:
  * Fixes
    + Use default for non ASCII characters in drawing
    + Maximum movie time
    + Guide updates
  * Enhancements
    + Updated translations
    + Lockout on failed authentications
    + Hardware decoding for some network cameras
    + User specification of ffmpeg options for network cameras
    + Change default processing for http cameras.
  * New Configuration Options
    + watchdog_tmo
    + watchdog_kill
    + pause
    + webcontrol_lock_minutes
    + webcontrol_lock_attempts
    + webcontrol_lock_max_ips
  * Renamed Configuration Options
    + vid_control_params -> video_params
    + mmalcam_control_params -> mmalcam_params
  * Changed Configuration Options
    + v4l2_palette use video_params
    + input use video_params
    + norm use video_params
    + frequency use video_params
    + netcam_highres use netcam_high_params
    + netcam_keepalive use netcam_params
    + netcam_proxy use netcam_params
    + netcam_tolerant_check use netcam_params
    + netcam_use_tcp use netcam_params
    + netcam_decoder use netcam_params
    + webcontrol_cors_header use webcontrol_header_params
    + stream_cors_header use stream_header_params
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Drop ProtectClock hardening, can cause issues if other device acceess is needed
* Wed Oct  6 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_motion.service.patch
* Tue Dec 22 2020 Dirk Müller <dmueller@suse.com>
- update to 4.3.2:
  * Revise to use MHD function for url decode
  * Update travis distribution testing
  * Eliminate compiler warnings on unsigned comparisons
  * Eliminate compiler warnings on MHD return codes
* Thu Jul  9 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 4.3.1
  * Fixes
    + Compiler errors with GCC 10
    + Overrides to CFLAGS
    + Add maintainer mode
    + Segfault when invalid camera directory specified
    + MariaDB initializations
    + Updated guide
- Update to 4.3.0
  * Fixes
    + Use default for non ASCII characters in drawing
    + Removed poll requirement for MHD
    + Implement revised configure and automake
    + Updated testing for travis
    + Revise MMAL to handle revisions from upstream.
    + Fix movie start times
    + Set the FPS on v4l2 devices
    + Consolidate the JPEG code processing
    + Fix substream processing for non modulo 16
    + Ignore invalid data sent from rtsp cameras.
    + Adjust the netcam handler wait and processing
    + Answer incorrect web requests.
    + Implement a delay upon excessive reconnect attempts
    + Fix filetype specified for snapshots
    + Guide updates
    + Fix vbr calculation for high frame rates
  * Enhancements
    + Updated translations
    + Implement revised directory structure
    + Implement optional decoder and encoders
    + Allow for distros that use videoio.h
    + Revise and enhance the sample service file
    + Output to the log the resulting ext pipe command
  * New Configuration Options
    + netcam_decoder
- Update to 4.2.2
  * Fixes
    + Webcontrol quit/end
    + Add stream_motion option
    + Generic tracking option
    + Delay stream when starting
    + Hostname for IPV6
    + Multiple source streams when using passthrough
    + Guide update
- Cleanup spec file
* Tue Feb 12 2019 bjorn.lie@gmail.com
- No longer force ffmpeg 3 versions of pkgconfig(libav*).
* Mon Jan 14 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to 4.2.1
  Fixes:
  - Stream rate calculations
  - Static library linking
  - Eliminate updates to movie_passthrough via webcontrol
  - Thread locking for movie_passthrough
  - NULL terminator for EXIF
  - Revised logging messages
  - Guide update for mobile
* Thu Nov  8 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Thu Jul 12 2018 meissner@suse.com
- explicitly require ffmpeg3-devel , as we currently
  do not build against ffmpeg4.
* Wed Mar  7 2018 mvetter@suse.com
- Update to 4.1.1:
  https://motion-project.github.io/motion_news.html
  Fixes:
  - Build on musl based systems
  - jpeg decompression error processing
  - image saving when using highres option
  - filename for debug movie correction
* Fri Nov 24 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Nov 24 2017 olaf@aepfle.de
- Use pkgconfig to refer to ffmpeg because ffmpeg-devel does not exist
- Use pkgconfig to refer to webp
- Remove unused zlib
* Wed Nov 15 2017 meissner@suse.com
- Merged things from packman.
  - Use an own motion user, in group video
  - sysconfig script for options in systemd service
* Tue Nov 14 2017 meissner@suse.com
- updated to 4.1 from github site.
  https://github.com/Motion-Project/motion/wiki/News
  - New or revised configuration options:
  - flip_axis (mirrors the image)
  - mask_privacy (blocks out areas of image)
  - netcam_highres (dual stream processing)
  - on_camera_found (script execution)
  - substream_port (low resolution output stream)
  - webcontrol_parms (Control what parameters are included on webcontrol)
  - ffmpeg_timelapse renamed to timelapse_interval
  - ffmpeg_timelapse_mode renamed to timelapse_mode
  - timelapse_fps (fps for the resulting video)
  - timelapse_codec (container/codec for timelapse)
  - sdl_threadnr removed
  - Revised functionality
  - Removed v4l1 functionality
  - Added support for RTMP and additional v4l2 palette options
  - Added support for network cameras on macOSX
  - Added additional conversion specifiers
  - Added flood control for Motion log
  - Revised INF/DBG message logging
  - Log IP of failed authentication attempts
  - Fixes
  - Movie playback issues
  - ffmpeg 3.1 warnings
  - v4l2 mjpg image corruptions
  - various other bug fixes/refactoring
  - Known Issues:
  - Recovery for sqlite from watchdog time out (#521)
  - Timing on images for round-robin devices (#363)
  - Unresponsive thread killing (#366)
  - Updates to documentation
  - Additional building instructions
  - Links to configuration options at top of documentation
  - Multiple rewrites for configuration options
  - Updates to required libraries
  - Added requirement for libavdevice
  - Removed requirement for libsdl
  - Removed requirement for libv4l
* Thu Dec  8 2011 oliver.bengs@opensuse.org
- imported from fedora specfile
- some cleanups
